/*
 * gsampler-client-device.h
 * Copyright (C) Lilian Monchalin 2011 <isaya07@users.sf.net>
 * 
 * gsampler is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * gsampler is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _GSAMPLER_CLIENT_DEVICE_H_
#define _GSAMPLER_CLIENT_DEVICE_H_

#include "gsampler-client.h"

#define GSAMPLER_TYPE_DEVICE_INFO (gsampler_device_info_get_type ())
typedef struct _GsamplerDeviceInfo GsamplerDeviceInfo;
struct _GsamplerDeviceInfo {
	gint id;
	gboolean active;
	gint type;
	gchar* driver;
	gchar* name;
	gint param;
	gdouble samplerate;
	gint fragments;
	gdouble fragmentsize;
};

typedef struct _GsamplerDeviceBinding GsamplerDeviceBinding;
struct _GsamplerDeviceBinding {
	gchar* type;
	gchar* name;
	gboolean active;
};

GType gsampler_device_info_get_type (void) G_GNUC_CONST;
GsamplerDeviceInfo* gsampler_device_info_dup (const GsamplerDeviceInfo* self);
void gsampler_device_info_copy (const GsamplerDeviceInfo* self, GsamplerDeviceInfo* dest);
void gsampler_device_info_destroy (GsamplerDeviceInfo* self);
void gsampler_device_info_free (GsamplerDeviceInfo* self);

GsamplerDeviceBinding* gsampler_device_binding_dup (const GsamplerDeviceBinding* self);
void gsampler_device_binding_destroy (GsamplerDeviceBinding* self);
void gsampler_device_binding_free (GsamplerDeviceBinding* self);


/*device*/
gchar** 	gsampler_client_get_available_audio_output (GsamplerClient* self);
gchar** 	gsampler_client_get_available_midi_input (GsamplerClient* self);
gint 		gsampler_client_create_audio_device (GsamplerClient* self, const gchar* type, const gchar* name);
gint 		gsampler_client_create_midi_device (GsamplerClient* self, const gchar* type, const gchar* name);
gboolean 	gsampler_client_delete_audio_device (GsamplerClient* self, gint id);
gboolean 	gsampler_client_delete_midi_device (GsamplerClient* self, gint id);
gchar** 	gsampler_client_get_audio_driver_list (GsamplerClient* self);
gint 		gsampler_client_get_audio_output_count (GsamplerClient* self);
gint 		gsampler_client_get_midi_input_count (GsamplerClient* self);
gchar** 	gsampler_client_get_midi_driver_list (GsamplerClient* self);
GsamplerDeviceInfo * 		gsampler_client_get_device_info (GsamplerClient* self, gint id, gint type);
gboolean 	gsampler_client_set_audio_output_parameter (GsamplerClient* self, gint id, const gchar* type, const gchar* val);
gboolean 	gsampler_client_set_midi_input_parameter (GsamplerClient* self, gint id, const gchar* type, const gchar* val);
GHashTable* gsampler_client_get_audio_output_channel_info (GsamplerClient* self, gint id, gint chan);
gchar** 	gsampler_client_get_audio_output_channel_parameter_info (GsamplerClient* self, gint id, gint chan, const gchar* param);
gboolean 	gsampler_client_set_audio_output_channel_parameter (GsamplerClient* self, gint id, gint chan, const gchar* param, const gchar* val);
GHashTable* gsampler_client_get_midi_input_port_info (GsamplerClient* self, gint id, gint port);
gchar** 	gsampler_client_get_midi_input_port_parameter_info (GsamplerClient* self, gint id, gint port, const gchar* param);
gboolean 	gsampler_client_set_midi_input_port_parameter (GsamplerClient* self, gint id, gint port, const gchar* param, const gchar* val);
GSList* 	gsampler_client_get_avail_device_parameter_bindings (GsamplerClient* self, gint type, gint id, gint chan_id);


#endif /* _GSAMPLER_CLIENT_DEVICE_H_ */